OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Nepareiza krātuve",
    "Unknown error" : "Nezināma kļūda",
    "All files" : "Visas datnes",
    "Saved" : "Saglabāts",
    "Home" : "Mājas",
    "Close" : "Aizvērt",
    "Favorites" : "Iecienītie",
    "Upload cancelled." : "Augšupielāde ir atcelta.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Neizdodas augšupielādēt {filename}, jo tā ir vai nu mape vai 0 baitu saturošs fails.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nav pietiekami daudz brīvas vietas. Tiek augšupielādēti {size1}, bet pieejami tikai {size2}",
    "Uploading..." : "Augšupielādē...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Notiek augšupielāde. Pametot lapu tagad, tiks atcelta augšupielāde.",
    "Actions" : "Darbības",
    "Download" : "Lejupielādēt",
    "Rename" : "Pārsaukt",
    "Delete" : "Dzēst",
    "Disconnect storage" : "Atvienot krātuvi",
    "Unshare" : "Pārtraukt dalīšanos",
    "Files" : "Datnes",
    "Details" : "Detaļas",
    "Select" : "Norādīt",
    "Pending" : "Gaida savu kārtu",
    "Unable to determine date" : "Neizdevās noteikt datumu",
    "This operation is forbidden" : "Šī darbība ir aizliegta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis direktorijs nav pieejams, lūdzu pārbaudiet žurnālus vai sazinieties ar administratoru",
    "Name" : "Nosaukums",
    "Size" : "Izmērs",
    "Modified" : "Mainīts",
    "_%n folder_::_%n folders_" : ["%n mapes","%n mape","%n mapes"],
    "_%n file_::_%n files_" : ["%n faili","%n fails","%n faili"],
    "{dirs} and {files}" : "{dirs} un {files}",
    "You don’t have permission to upload or create files here" : "Jums nav tiesību, augšupielādēt vai veidot, šeit datnes",
    "_Uploading %n file_::_Uploading %n files_" : ["%n","Augšupielāde %n failu","Augšupielāde %n failus"],
    "New" : "Jauna",
    "\"{name}\" is an invalid file name." : "\"{name}\" ir nepareizs datnes nosaukums.",
    "File name cannot be empty." : "Datnes nosaukums nevar būt tukšs.",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsu krātuve ir pilna, datnes vairs nevar augšupielādēt vai sinhronizēt!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Jūsu krātuve ir gandrīz pilna ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["atrasts pēc '{filter}'","atrasts pēc '{filter}'","atrasti pēc '{filter}'"],
    "Favorited" : "Favorīti",
    "Favorite" : "Iecienītais",
    "Folder" : "Mape",
    "New folder" : "Jauna mape",
    "Upload" : "Augšupielādēt",
    "An error occurred while trying to update the tags" : "Atjaunojot atzīmes notika kļūda",
    "A new file or folder has been <strong>created</strong>" : "<strong>Izveidots</strong> jauns fails vai mape",
    "A file or folder has been <strong>changed</strong>" : "<strong>Izmainīts</strong> fails vai mape",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Dzēsts</strong> fails vai mape",
    "A file or folder has been <strong>restored</strong>" : "<strong>Atjaunots</strong> fails vai mape",
    "You created %1$s" : "Tu izveidoji %1$s",
    "%2$s created %1$s" : "%2$s izveidoja %1$s",
    "%1$s was created in a public folder" : "%1$s tika izveidots publiskajā mapē",
    "You changed %1$s" : "Tu izmainīji %1$s",
    "%2$s changed %1$s" : "%2$s izmainīja %1$s",
    "You deleted %1$s" : "Tu izdzēsi %1$s",
    "%2$s deleted %1$s" : "%2$s izdzēsa %1$s",
    "You restored %1$s" : "Tu atjaunoji %1$s",
    "%2$s restored %1$s" : "%2$s atjaunoja %1$s",
    "Upload (max. %s)" : "Augšupielādēt (maks. %s)",
    "File handling" : "Datņu pārvaldība",
    "Maximum upload size" : "Maksimālais datņu augšupielādes apjoms",
    "max. possible: " : "maksimālais iespējamais:",
    "Save" : "Saglabāt",
    "Settings" : "Iestatījumi",
    "WebDAV" : "WebDAV",
    "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Select all" : "Atzīmēt visu",
    "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
    "No favorites" : "Nav favorītu",
    "Files and folders you mark as favorite will show up here" : "Faili un mapes, ko atzīmēsit kā favorītus, tiks rādīti šeit",
    "Text file" : "Teksta datne"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
